# mpddrp
[![license](https://img.shields.io/github/license/AKurushimi/mpddrp?style=flat-square)](https://www.gnu.org/licenses/gpl-3.0.en.html)
[![python](https://img.shields.io/pypi/pyversions/mpddrp?style=flat-square)](https://www.python.org/)
[![pypi](https://img.shields.io/pypi/v/mpddrp?style=flat-square)](https://pypi.org/project/mpddrp/)
[![pypresence](https://img.shields.io/badge/using-pypresence-00bb88.svg?style=flat-square&logo=discord&logoWidth=20)](https://github.com/qwertyquerty/pypresence)

mpddrp is a simple python script that displays what you're currently listening to through MPD on Discord.

## Dependencies

* [pypresence](https://github.com/qwertyquerty/pypresence)
* [python-mpd2](https://github.com/Mic92/python-mpd2)

## How to install?

Using PyPI: 

`pip install mpddrp`

From source:

`python setup.py install`

## Configuration

Linux/MacOS:

`$HOME/.config/mpddrp/config.json`

Windows:

`C:/Users/USERNAME/AppData/Roaming/mpddrp/config.json`
